@@ -17,12 +17,16 @@ class Theme(models.Model):
     tab_logo = models.ImageField(
         "TAB_LOGO", max_length=300, null=True, upload_to="theme"
     )
+    login_logo = models.ImageField(
+        "LOGIN_LOGO", max_length=300, null=True, upload_to="theme"
+    )
 
     def to_dict(self):
         return {
             "title": self.title,
             "corporate_logo": self.corporate_logo.url,
             "tab_logo": self.tab_logo.url,
+            "login_logo": self.login_logo.url,
             "self_color": self.theme_color,
             "aux_color": self.aux_color,
         }
