@@ -8,7 +8,9 @@ class ThemeCase:
     create a sample theme
     """
 
-    def __init__(self, corporate_logo_path="fixtures/test_file/image.jpg", tab_logo_path="fixtures/test_file/AAV43679.png"):
+    def __init__(self, corporate_logo_path="theme/theme/logo.jpg",
+                 tab_logo_path="theme/theme/tab_logo.png",
+                 login_logo_path="theme/theme/login.jpg"):
         self.theme = {
             "title": "天和双利",
             "theme_color": "#e60000",
@@ -22,21 +24,32 @@ class ThemeCase:
         self.theme_object.tab_logo.save(
             "tab_logo.png", File(open(tab_logo_path, "rb"))
         )
+        self.theme_object.login_logo.save(
+            "login_logo.jpg", File(open(login_logo_path, "rb"))
+        )
 
     def attach_file(self):
         return [
             (
                 "corporate_logo",
-                ("logo.jpg", open("fixtures/test_file/image.jpg", "rb"), "image/jpg"),
+                ("logo.jpg", open("theme/theme/logo.jpg", "rb"), "image/jpg"),
             ),
             (
                 "tab_logo",
                 (
                     "tab_logo.png",
-                    open("fixtures/test_file/AAV43679.png", "rb"),
+                    open("theme/theme/tab_logo.png", "rb"),
                     "image/png",
                 ),
             ),
+            (
+                "login_logo",
+                (
+                    "login_logo.jpg",
+                    open("theme/theme/login.jpg", "rb"),
+                    "image/jpg",
+                ),
+            ),
         ]
 
     def create_theme(self):
